==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/fa.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "اشتراک سرور به سرور در این سرور فعال نیست .",
    "Invalid or untrusted SSL certificate" : "گواهینامه SSL غیر قابل اعتماد یا غیر معتبر است.",
    "Couldn't add remote share" : "امکان افزودن اشتراک گذاری از راه دور وجود ندارد",
    "Shared with you" : "موارد به اشتراک گذاشته شده با شما",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "Shared by link" : "اشتراک گذاشته شده از طریق پیوند",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "آیا مایل به افزودن اشتراک از راه دور {name} از {owner}@{remote} هستید.",
    "Remote share" : "اشتراک از راه دور",
    "Remote share password" : "رمز عبور اشتراک از راه دور",
    "Cancel" : "منصرف شدن",
    "Add remote share" : "افزودن اشتراک از راه دور",
    "Invalid ownCloud url" : "آدرس نمونه ownCloud  غیر معتبر است",
    "Share" : "اشتراک‌گذاری",
    "Shared by" : "اشتراک گذاشته شده به وسیله",
    "A file or folder has been <strong>shared</strong>" : "فایل یا پوشه ای به <strong>اشتراک</strong> گذاشته شد",
    "You shared %1$s with %2$s" : "شما %1$s را با %2$s به اشتراک گذاشتید",
    "You shared %1$s with group %2$s" : "شما %1$s را با گروه %2$s به اشتراک گذاشتید",
    "%2$s shared %1$s with you" : "%2$s مورد %1$s را با شما به اشتراک گذاشت",
    "You shared %1$s via link" : "شما %1$s را توسط پیوند به اشتراک گذاشتید",
    "Shares" : "موارد به اشتراک گذاشته",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Password" : "گذرواژه",
    "Name" : "نام",
    "Share time" : "زمان به اشتراک گذاری",
    "Sorry, this link doesn’t seem to work anymore." : "متاسفانه این پیوند دیگر کار نمی کند",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link expired" : "این پیوند منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "For more info, please ask the person who sent this link." : "برای اطلاعات بیشتر، لطفا از شخصی که این پیوند را ارسال کرده سوال بفرمایید.",
    "Add to your ownCloud" : "افزودن به ownCloud شما",
    "Download" : "دانلود",
    "Download %s" : "دانلود %s",
    "Direct link" : "پیوند مستقیم"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/fa.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "اشتراک سرور به سرور در این سرور فعال نیست .",
    "Invalid or untrusted SSL certificate" : "گواهینامه SSL غیر قابل اعتماد یا غیر معتبر است.",
    "Could not authenticate to remote share, password might be wrong" : "احرازهویت برای اشتراک‌گذاری راه‌دور انجام نشد، احتمالا رمزعبور نادرست است",
    "Storage not valid" : "فضای ذخیره‌سازی معتبر نیست",
    "Couldn't add remote share" : "امکان افزودن اشتراک گذاری از راه دور وجود ندارد",
    "Shared with you" : "موارد به اشتراک گذاشته شده با شما",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "Shared by link" : "اشتراک گذاشته شده از طریق پیوند",
    "Nothing shared with you yet" : "هیچ موردی با شما به اشتراک گذاشته نشده است",
    "Nothing shared yet" : "هیچ موردی تاکنون به اشتراک گذاشته نشده است",
    "No shared links" : "هیچ لینک اشتراک‌گذاری وجود ندارد",
    "Files and folders you share by link will show up here" : "فایل‌ها و پوشه‌های اشتراک‌گذاشته توسط شما همراه با لینک در اینجا نمایش داده خواهد شد",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "آیا مایل به افزودن اشتراک از راه دور {name} از {owner}@{remote} هستید.",
    "Remote share" : "اشتراک از راه دور",
    "Remote share password" : "رمز عبور اشتراک از راه دور",
    "Cancel" : "منصرف شدن",
    "Add remote share" : "افزودن اشتراک از راه دور",
    "You can upload into this folder" : "می‌توانید در این پوشه آپلود کنید",
    "Invalid ownCloud url" : "آدرس نمونه ownCloud  غیر معتبر است",
    "Shared by" : "اشتراک گذاشته شده به وسیله",
    "Sharing" : "اشتراک گذاری",
    "A file or folder has been <strong>shared</strong>" : "فایل یا پوشه ای به <strong>اشتراک</strong> گذاشته شد",
    "You shared %1$s with %2$s" : "شما %1$s را با %2$s به اشتراک گذاشتید",
    "You shared %1$s with group %2$s" : "شما %1$s را با گروه %2$s به اشتراک گذاشتید",
    "You shared %1$s via link" : "شما %1$s را توسط پیوند به اشتراک گذاشتید",
    "%2$s shared %1$s with you" : "%2$s مورد %1$s را با شما به اشتراک گذاشت",
    "Shares" : "موارد به اشتراک گذاشته",
    "Accept" : "قبول",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Password" : "گذرواژه",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Name" : "نام",
    "Share time" : "زمان به اشتراک گذاری",
    "Sorry, this link doesn’t seem to work anymore." : "متاسفانه این پیوند دیگر کار نمی کند",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link expired" : "این پیوند منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "For more info, please ask the person who sent this link." : "برای اطلاعات بیشتر، لطفا از شخصی که این پیوند را ارسال کرده سوال بفرمایید.",
    "Add to your ownCloud" : "افزودن به ownCloud شما",
    "Download" : "دانلود",
    "Download %s" : "دانلود %s",
    "Direct link" : "پیوند مستقیم",
    "Open documentation" : "بازکردن مستند",
    "HTML Code:" : "کد HTML :"
},
"nplurals=1; plural=0;");
